@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-04-07'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,20 +29,26 @@ sub _has_cats {
 }
 
 sub _add_category_from_spec {
-    my ($thing, $spec, $noun, $has_cats) = @_;
+    my ($cats_spec, $thing, $spec, $noun, $has_cats) = @_;
     my $cat;
     my $raw_cat = '';
+    my $order;
     for (@{ $spec->{tags} // [] }) {
         my $tag_name = ref($_) ? $_->{name} : $_;
         if ($tag_name =~ /^category:(.+)/) {
             $raw_cat = $1;
-            $cat = ucfirst($1) . " " . $noun;
+
+            $cat = ucfirst($1);
+            $cat =~ s/-/ /g;
+            $cat .= " " . $noun;
+            $order = 50;
             last;
         }
     }
-    $cat //= $has_cats ? "General $noun" : ucfirst($noun); # XXX translatable?
+    $cat //= $has_cats ? "Other $noun" : ucfirst($noun); # XXX translatable?
+    $order //= 99;
     $thing->{category} = $cat;
-    $thing->{raw_category} = $raw_cat;
+    $cats_spec->{$cat}{order} //= $order;
 }
 
 sub _add_default_from_arg_spec {
@@ -171,7 +177,10 @@ sub gen_cli_doc_data_from_meta {
     $ggls_res->[0] == 200 or return $ggls_res;
 
     my $args_prop = $meta->{args} // {};
-    my $clidocdata = {};
+    my $clidocdata = {
+        option_categories => {},
+        example_categories => {},
+    };
 
     # generate usage line
     {
@@ -210,8 +219,6 @@ sub gen_cli_doc_data_from_meta {
     # generate list of options
     my %opts;
     {
-        my $has_cats = _has_cats([values %$args_prop]);
-
         my $ospecs = $ggls_res->[3]{'func.specmeta'};
         # separate groupable aliases because they will be merged with the
         # argument options
@@ -237,12 +244,12 @@ sub gen_cli_doc_data_from_meta {
         while (@k) {
             my $k = shift @k;
             my $ospec = $ospecs->{$k};
+            my $opt;
             my $optkey;
 
             if ($ospec->{is_alias} || defined($ospec->{arg})) {
                 my $arg_spec;
                 my $alias_spec;
-                my $opt;
 
                 if ($ospec->{is_alias}) {
                     # non-groupable alias
@@ -337,11 +344,10 @@ sub gen_cli_doc_data_from_meta {
                     $opt->{$_} = $arg_spec->{$_} if defined $arg_spec->{$_};
                 }
 
-                _add_category_from_spec($opt, $arg_spec, "options", $has_cats);
+                _add_category_from_spec($clidocdata->{option_categories},
+                                        $opt, $arg_spec, "options", 1);
                 _add_default_from_arg_spec($opt, $arg_spec);
 
-                $opts{$optkey} = $opt;
-
             } else {
                 # option from common_opts
 
@@ -361,10 +367,9 @@ sub gen_cli_doc_data_from_meta {
 
                 $optkey = _fmt_opt($spec, $ospec);
                 my $rimeta = rimeta($spec);
-                $opts{$optkey} = {
+                $opt = {
                     opt_parsed => $ospec->{parsed},
                     orig_opt => $k,
-                    category => $has_cats ? "General options" : "Options", # XXX translatable?
                     summary => $show_neg ?
                         $rimeta->langprop({lang=>$lang}, 'summary.alt.bool.not') :
                             $rimeta->langprop({lang=>$lang}, 'summary'),
@@ -376,7 +381,12 @@ sub gen_cli_doc_data_from_meta {
                     (default => $spec->{default}) x !!(exists($spec->{default}) && !$show_neg),
                 };
 
+                _add_category_from_spec($clidocdata->{option_categories},
+                                        $opt, $spec, "options", 1);
+
             }
+
+            $opts{$optkey} = $opt;
         }
 
         # link ungrouped alias to its main opt
@@ -441,7 +451,8 @@ sub gen_cli_doc_data_from_meta {
                 example_spec => $eg,
             };
             # XXX show result from $eg
-            _add_category_from_spec($egdata, $eg, "examples", $has_cats);
+            _add_category_from_spec($clidocdata->{example_categories},
+                                    $egdata, $eg, "examples", $has_cats);
             push @examples, $egdata;
         }
     }
@@ -465,7 +476,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.17 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-04-02.
+This document describes version 0.18 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-04-07.
 
 =head1 SYNOPSIS
 
@@ -512,6 +523,7 @@ Sample result:
      200,
      "OK",
      {
+       example_categories => { Examples => { order => 99 } },
        examples => [
          {
            category     => "Examples",
@@ -522,43 +534,44 @@ Sample result:
                              summary => "Summary for an example",
                              test    => 0,
                            },
-           raw_category => "",
            summary      => "Summary for an example",
          },
        ],
+       option_categories => {
+         "Cat1 options"  => { order => 50 },
+         "Other options" => { order => 99 },
+       },
        opts => {
          "--bool1" => {
-           arg          => "bool1",
-           arg_spec     => {
-                             cmdline_aliases => { z => { summary => "This is summary for option `-z`" } },
-                             schema => ["bool", {}, {}],
-                             summary => "Another bool option",
-                             tags => ["category:cat1"],
-                           },
-           category     => "Cat1 options",
-           description  => undef,
-           fqarg        => "bool1",
-           opt_parsed   => { opts => ["bool1"] },
-           orig_opt     => "bool1",
-           raw_category => "cat1",
-           summary      => "Another bool option",
-           tags         => 'fix',
+           arg         => "bool1",
+           arg_spec    => {
+                            cmdline_aliases => { z => { summary => "This is summary for option `-z`" } },
+                            schema => ["bool", {}, {}],
+                            summary => "Another bool option",
+                            tags => ["category:cat1"],
+                          },
+           category    => "Cat1 options",
+           description => undef,
+           fqarg       => "bool1",
+           opt_parsed  => { opts => ["bool1"] },
+           orig_opt    => "bool1",
+           summary     => "Another bool option",
+           tags        => 'fix',
          },
          "--flag1, -f" => {
-           arg          => "flag1",
-           arg_spec     => {
-                             cmdline_aliases => { f => {} },
-                             schema => ["bool", { is => 1 }, {}],
-                             tags => ["category:cat1"],
-                           },
-           category     => "Cat1 options",
-           description  => undef,
-           fqarg        => "flag1",
-           opt_parsed   => { opts => ["flag1"] },
-           orig_opt     => "flag1",
-           raw_category => "cat1",
-           summary      => undef,
-           tags         => 'fix',
+           arg         => "flag1",
+           arg_spec    => {
+                            cmdline_aliases => { f => {} },
+                            schema => ["bool", { is => 1 }, {}],
+                            tags => ["category:cat1"],
+                          },
+           category    => "Cat1 options",
+           description => undef,
+           fqarg       => "flag1",
+           opt_parsed  => { opts => ["flag1"] },
+           orig_opt    => "flag1",
+           summary     => undef,
+           tags        => 'fix',
          },
          "--str1=s*" => {
            arg => "str1",
@@ -568,31 +581,29 @@ Sample result:
              schema => ["str", { req => 1 }, {}],
              summary => "A required option as well as positional argument",
            },
-           category => "General options",
+           category => "Other options",
            description => undef,
            fqarg => "str1",
            opt_parsed => { desttype => "", opts => ["str1"], type => "s" },
            orig_opt => "str1=s",
            pos => 0,
-           raw_category => "",
            req => 1,
            summary => "A required option as well as positional argument",
          },
          "-z" => {
-           alias_for    => "bool1",
-           alias_spec   => 'fix',
-           arg          => "bool1",
-           arg_spec     => 'fix',
-           category     => "Cat1 options",
-           description  => undef,
-           fqarg        => "bool1",
-           is_alias     => 1,
-           main_opt     => "--bool1",
-           opt_parsed   => { opts => ["z"] },
-           orig_opt     => "z",
-           raw_category => "cat1",
-           summary      => "This is summary for option `-z`",
-           tags         => 'fix',
+           alias_for   => "bool1",
+           alias_spec  => 'fix',
+           arg         => "bool1",
+           arg_spec    => 'fix',
+           category    => "Cat1 options",
+           description => undef,
+           fqarg       => "bool1",
+           is_alias    => 1,
+           main_opt    => "--bool1",
+           opt_parsed  => { opts => ["z"] },
+           orig_opt    => "z",
+           summary     => "This is summary for option `-z`",
+           tags        => 'fix',
          },
        },
        usage_line => "[[prog]] [options] <str1>",
@@ -609,6 +620,12 @@ Sample result:
 For a more complete sample, see function metadata for C<demo_cli_opts> in
 L<Perinci::Examples::CLI>.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>, L<Perinci::CmdLine::Lite>
+
+L<Pod::Weaver::Plugin::Rinci>
+
 =head1 FUNCTIONS
 
 
@@ -670,12 +687,6 @@ that contains extra information.
 
 Return value:  (hash)
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>, L<Perinci::CmdLine::Lite>
-
-L<Pod::Weaver::Plugin::Rinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-To-CLIDocData>.
